[clang-tools-extra] r228693 - Renamed module.map to module.modulemap (modularize).

John Thompson John.Thompson.JTSoftware at gmail.com
Tue Feb 10 06:45:30 PST 2015


Author: jtsoftware
Date: Tue Feb 10 08:45:30 2015
New Revision: 228693

URL: http://llvm.org/viewvc/llvm-project?rev=228693&view=rev
Log:
Renamed module.map to module.modulemap (modularize).

Modified:
    clang-tools-extra/trunk/modularize/Modularize.cpp
    clang-tools-extra/trunk/modularize/ModuleAssistant.cpp

Modified: clang-tools-extra/trunk/modularize/Modularize.cpp
URL: http://llvm.org/viewvc/llvm-project/clang-tools-extra/trunk/modularize/Modularize.cpp?rev=228693&r1=228692&r2=228693&view=diff
==============================================================================
--- clang-tools-extra/trunk/modularize/Modularize.cpp (original)
+++ clang-tools-extra/trunk/modularize/Modularize.cpp Tue Feb 10 08:45:30 2015
@@ -90,16 +90,17 @@
 //
 // See PreprocessorTracker.cpp for additional details.
 //
-// Modularize also has an option ("-module-map-path=module.map") that will
-// skip the checks, and instead act as a module.map generation assistant,
+// Modularize also has an option ("-module-map-path=module.modulemap") that will
+// skip the checks, and instead act as a module.modulemap generation assistant,
 // generating a module map file based on the header list.  An optional
 // "-root-module=(rootName)" argument can specify a root module to be
-// created in the generated module.map file.  Note that you will likely
+// created in the generated module.modulemap file.  Note that you will likely
 // need to edit this file to suit the needs of your headers.
 //
-// An example command line for generating a module.map file:
+// An example command line for generating a module.modulemap file:
 //
-//   modularize -module-map-path=module.map -root-module=myroot headerlist.txt
+//   modularize -module-map-path=module.modulemap -root-module=myroot \
+//      headerlist.txt
 //
 // Note that if the headers in the header list have partial paths, sub-modules
 // will be created for the subdirectires involved, assuming that the
@@ -679,7 +680,7 @@ int main(int Argc, const char **Argv) {
   // Save program name for error messages.
   Argv0 = Argv[0];
 
-  // Save program arguments for use in module.map comment.
+  // Save program arguments for use in module.modulemap comment.
   CommandLine = sys::path::stem(sys::path::filename(Argv0));
   for (int ArgIndex = 1; ArgIndex < Argc; ArgIndex++) {
     CommandLine.append(" ");

Modified: clang-tools-extra/trunk/modularize/ModuleAssistant.cpp
URL: http://llvm.org/viewvc/llvm-project/clang-tools-extra/trunk/modularize/ModuleAssistant.cpp?rev=228693&r1=228692&r2=228693&view=diff
==============================================================================
--- clang-tools-extra/trunk/modularize/ModuleAssistant.cpp (original)
+++ clang-tools-extra/trunk/modularize/ModuleAssistant.cpp Tue Feb 10 08:45:30 2015
@@ -129,7 +129,7 @@ Module *Module::findSubModule(llvm::Stri
 
 // Implementation functions:
 
 // Reserved keywords in module.map syntax.
 // Keep in sync with keywords in module map parser in Lex/ModuleMap.cpp,
 // such as in ModuleMapParser::consumeToken().
 static const char *ReservedNames[] = {
@@ -175,7 +175,7 @@ static bool addModuleDescription(Module
   if (Count != 0) {
     llvm::errs() << "warning: " << FilePath
                  << " depends on other headers being included first,"
-                    " meaning the module.map won't compile."
+                    " meaning the module.modulemap won't compile."
                     "  This header will be omitted from the module map.\n";
     return true;
   }
@@ -129,7 +129,7 @@ Module *Module::findSubModule(llvm::Stri
 // Implementation functions:
 
-// Reserved keywords in module.map syntax.
+// Reserved keywords in module.modulemap syntax.
 // Keep in sync with keywords in module map parser in Lex/ModuleMap.cpp,
 // such as in ModuleMapParser::consumeToken().





More information about the cfe-commits mailing list